@@ -16,12 +16,14 @@ from strawberry.types.fields.resolver import (
     ReservedType,
     StrawberryResolver,
 )
+from strawberry.unset import UNSET
 
 
-def directive_field(name: str) -> Any:
+def directive_field(name: str, default: object = UNSET) -> Any:
     return StrawberryField(
         python_name=None,
         graphql_name=name,
+        default=default,
     )
 
 
