@@ -3,6 +3,7 @@ from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Union, cast
 
 from typing_extensions import Final
 
+import mypy
 from mypy.nodes import (
     ARG_OPT,
     ARG_POS,
@@ -66,6 +67,12 @@ try:
 except ImportError:
     TypeVarDef = TypeVarType
 
+# To be compatible with user who don't use pydantic
+try:
+    from pydantic.mypy import METADATA_KEY as PYDANTIC_METADATA_KEY, PydanticModelField
+except ImportError:
+    PYDANTIC_METADATA_KEY = ""
+
 
 class MypyVersion:
     """Stores the mypy version to be used by the plugin"""
@@ -388,13 +395,54 @@ def strawberry_pydantic_class_callback(ctx: ClassDefContext) -> None:
         ]
         add_method(ctx, "__init__", init_args, NoneType())
 
-        model_type = _get_type_for_expr(model_expression, ctx.api)
+        model_type = cast(
+            mypy.types.Instance, _get_type_for_expr(model_expression, ctx.api)
+        )
+
+        # these are the fields that the user added to the strawberry type
+        new_strawberry_fields: Set[str] = set()
+
+        # TODO: think about inheritance for strawberry?
+        for stmt in ctx.cls.defs.body:
+            if isinstance(stmt, AssignmentStmt):
+                lhs = cast(NameExpr, stmt.lvalues[0])
+                new_strawberry_fields.add(lhs.name)
+
+        pydantic_fields: Set["PydanticModelField"] = set()
+        try:
+            for name, data in model_type.type.metadata[PYDANTIC_METADATA_KEY][
+                "fields"
+            ].items():
+                field = PydanticModelField.deserialize(ctx.cls.info, data)
+                pydantic_fields.add(field)
+        except KeyError:
+            # this will happen if the user didn't add the pydantic plugin
+            # AND is using the pydantic conversion decorator
+            ctx.api.fail(
+                "Pydantic plugin not installed,"
+                " please add pydantic.mypy your mypy.ini plugins",
+                ctx.reason,
+            )
+
+        missing_pydantic_fields: Set["PydanticModelField"] = set(
+            f for f in pydantic_fields if f.name not in new_strawberry_fields
+        )
 
         # Add to_pydantic
+        # TODO: Only add this if not manually defined
         add_method(
             ctx,
             "to_pydantic",
-            args=[],
+            args=[
+                f.to_argument(
+                    # TODO: use_alias should depend on config?
+                    info=model_type.type,
+                    typed=True,
+                    force_optional=False,
+                    use_alias=True,
+                )
+                for f in missing_pydantic_fields
+            ],
             return_type=model_type,
         )
 
